@@ -1258,6 +1258,40 @@ class StandardFunction:
 
         return np.array([prob[np.where(value > x_step)][-1] for value in x])
 
+    @staticmethod
+    def stress_strain_elem_history(object_data: dict, selection_tension_compression: str, integration_point: str, element_id: int):
+        """
+
+        Returns:
+        """
+        part_ids = object_data["part_ids"]
+        part_data = object_data["part_data"]
+        part_idx = object_data["part_idx"]
+
+        obj_calc = ObjectCalcUtil()
+        (function_overall_tension_compression, integration_point_function) = \
+            obj_calc.retrieve_functions(selection_tension_compression, integration_point)
+
+        result_data = []
+        for part_id in part_ids:
+            index = part_idx[part_id]
+            data = part_data[part_id]
+
+            row_ids = np.where(part_idx[part_id][:, 0] == element_id)[0]
+            if len(row_ids) == 0:
+                continue
+
+            row_ids = np.where(index[:, 0] == element_id)[0]
+            reduced_integration_point_data = integration_point_function(data[:, row_ids, :], axis=1)
+            result_data = function_overall_tension_compression(reduced_integration_point_data, axis=1)
+            result_data = result_data[~np.isnan(result_data)]
+
+            break
+
+        return result_data
+
+
+
     @staticmethod
     def stress_strain_part_max(object_data: dict, selection_tension_compression: str, integration_point: str,
                                nr_largest_elements: float):
@@ -1314,7 +1348,7 @@ class StandardFunction:
 
     @staticmethod
     def stress_strain_time_history(object_data: dict, selection_tension_compression: str, integration_point: str,
-                               percentile: float, interpolation:str):
+                                   percentile: float, interpolation:str):
         """
 
         Args:
@@ -1604,3 +1638,85 @@ class StandardFunction:
 
         a3ms_values = np.array([np.min(a_res[ind_tuple[0]:ind_tuple[1]]) for ind_tuple in ls_ind])
         return a3ms_values.reshape((-1, 1))
+
+    @staticmethod
+    def hit(contact_force: pint.Quantity, time: pint.Quantity):
+        """
+        Args:
+          contact_force: pint.Quantity:
+          time: pint.Quantity:
+
+        Returns:
+
+        """
+        assert np.any(contact_force)
+        return time[np.where(contact_force != 0)][0]
+
+    @staticmethod
+    def hit_vel_res(contact_force: pint.Quantity, head_vel_x: pint.Quantity, head_vel_y: pint.Quantity,
+                    head_vel_z: pint.Quantity,
+                    time_nodout: pint.Quantity, time_rcf: pint.Quantity):
+        """
+        Args:
+          contact_force: pint.Quantity:
+          head_vel_x: pint.Quantity:
+          head_vel_y: pint.Quantity:
+          head_vel_z: pint.Quantity:
+          time_nodout: pint.Quantity:
+          time_rcf: pint.Quantity:
+
+        Returns:
+
+        """
+        assert np.any(contact_force)
+        index = np.where(contact_force != 0)
+        new_index = np.argmin(np.abs(time_nodout.to_base_units() - time_rcf.to_base_units()[index][0]))
+        vels = np.hstack((head_vel_x, head_vel_y, head_vel_z))
+        head_impact_velocity = np.linalg.norm(vels._magnitude, axis=1)
+
+        return head_impact_velocity[new_index - 1]
+
+    @staticmethod
+    def hit_ang(contact_force: pint.Quantity, head_vel_x: pint.Quantity, head_vel_y: pint.Quantity,
+                    head_vel_z: pint.Quantity,
+                    time_nodout: pint.Quantity, time_rcf: pint.Quantity):
+        """
+        Args:
+          contact_force: pint.Quantity:
+          head_vel_x: pint.Quantity:
+          head_vel_y: pint.Quantity:
+          head_vel_z: pint.Quantity:
+          time_nodout: pint.Quantity:
+          time_rcf: pint.Quantity:
+
+        Returns:
+
+        """
+        assert np.any(contact_force)
+        index = np.where(contact_force != 0)
+        new_index = np.argmin(np.abs(time_nodout.to_base_units() - time_rcf.to_base_units()[index][0]))
+        vels = np.hstack((head_vel_x, head_vel_y, head_vel_z))
+        vels_xy = np.hstack((head_vel_x, head_vel_y))
+
+        head_impact_velocity = np.linalg.norm(vels._magnitude, axis=1)
+        head_impact_velocity_xy = np.linalg.norm(vels_xy._magnitude, axis=1)
+        head_impact_angle = np.rad2deg(np.arccos((head_impact_velocity_xy / head_impact_velocity)))
+
+        return head_impact_angle[new_index]
+
+    @staticmethod
+    def hit_vel(contact_force: pint.Quantity, vel: pint.Quantity,
+                time_nodout: pint.Quantity, time_rcf: pint.Quantity):
+        """
+        Args:
+          contact_force: pint.Quantity:
+          vel: pint.Quantity:
+          time_nodout: pint.Quantity
+          time_rcf: pint.Quantity
+
+        Returns:
+
+        """
+        assert np.any(contact_force)
+        index = np.where(contact_force != 0)
+        return vel[np.argmin(np.abs(time_nodout.to_base_units() - time_rcf.to_base_units()[index][0])) - 1]
\ No newline at end of file
