@@ -1,6 +1,6 @@
 
 from ..data.ls_dyna import DEForc, Elout, EloutObject, Glstat, Matsum, Nodout, RCForc, SBTout, SlipringOut, Secforc, Disbout, \
-                           PartDisbout, Abstat, AbstatCPM, JointForc, Sleout, RigidBody, BoundaryCondition
+                           PartDisbout, Abstat, AbstatCPM, JointForc, Sleout, RigidBody, BoundaryCondition, JointType
 from ..utils.constants import ObjectConstantsForData
 
 
@@ -20,6 +20,7 @@ class DataContainer:
     _deforc = None
     _nodout = None
     _joint_forc = None
+    _joint_type = None
     _volume = None
     _sbtout = None
     _slipringout = None
@@ -56,6 +57,8 @@ class DataContainer:
             return DataContainer._nodout
         elif name == ObjectConstantsForData.JOINT:
             return DataContainer._joint_forc
+        elif name == ObjectConstantsForData.JOINT_TYPE:
+            return DataContainer._joint_type
         elif name == ObjectConstantsForData.SEAT_BELT:
             return DataContainer._sbtout
         elif name == ObjectConstantsForData.SLIP_RING:
@@ -101,6 +104,7 @@ class DataContainer:
         DataContainer._elout_object = EloutObject(binout, logger, dynasaur_def, volume_path=volume_path)
         DataContainer._nodout = Nodout(binout, logger, dynasaur_def)
         DataContainer._joint_forc = JointForc(binout, logger, dynasaur_def)
+        DataContainer._joint_type = JointType(binout, logger, dynasaur_def)
         DataContainer._deforc = DEForc(binout, logger, dynasaur_def)
         DataContainer._disbout = Disbout(binout, logger, dynasaur_def)
         DataContainer._part_disbout = PartDisbout(binout, logger, dynasaur_def)
