@@ -458,6 +458,25 @@ class DynasaurDefinitions:
             for i in range(json_object["elem_range"][0], json_object["elem_range"][1]):
                 self._objects[name].add_element(i)
 
+    def _offset_ids(self, offset):
+        """update id on offset
+
+        Args:
+          json_objects:
+
+        Returns:
+
+        """
+        for object_name in offset:
+            for key_ in self._dynasaur_data_type_container[object_name]:
+                for index, value_ in enumerate(self._dynasaur_data_type_container[object_name][key_]):
+                    if object_name == ObjectConstantsForData.CONTACT:
+                        offset_value = int(value_[:-1]) + offset[object_name]
+                        self._dynasaur_data_type_container[object_name][key_][index] = str(offset_value) + value_[-1]
+                    else:
+                        assert isinstance(value_, int) and isinstance(offset[object_name], int)
+                        self._dynasaur_data_type_container[object_name][key_][index] = value_ + offset[object_name]
+
     def _parse_objects(self, json_objects):
         """parse json objects and call setter
 
@@ -484,6 +503,9 @@ class DynasaurDefinitions:
                 data_type_container = self._dynasaur_data_type_container[json_object[JsonConstants.TYPE]]
                 self._set_datacontainer_defintion(json_object, data_type_container)
 
+        if DefinitionConstants.OFFSET in json_objects:
+            self._offset_ids(json_objects[DefinitionConstants.OFFSET])
+
     def _set_criteria(self, json_object):
         """set criteria object
 
@@ -587,6 +609,9 @@ class DynasaurDefinitions:
                                 elif DefinitionConstants.OBJECTS in j_object:
                                     self._parse_objects(json_objects)
 
+                                elif DefinitionConstants.OFFSET in j_object:
+                                    pass
+
                                 else:
                                     self._logger.emit(LOGConstants.ERROR[0],
                                                       "json object not understood:" + str(j_object))
