@@ -625,14 +625,19 @@ class EloutObject(BinoutData):
         Returns:
 
         """
+
+        mat = []
+        ids = []
+        ipts = []
         if ((elout_elem == "shell" or elout_elem == "beam") and what == "stress"):
             # ok
             nip = np.tile(self._binout.read(self._name, elout_elem, 'nip')[0], time.shape[0]).flatten()
-            mat = np.repeat(np.tile(self._binout.read(self._name, elout_elem, 'mat')[0], time.shape[0]).flatten(),
-                            nip).reshape((-1, 1))
-            ipts = self._concatenated_ranges(nip).reshape(-1, 1)
-            ids = np.repeat(np.tile(self._binout.read(self._name, elout_elem, 'ids')[0], time.shape[0]).flatten(),
-                            nip).reshape((-1, 1))
+            if len(nip) != 0:
+                mat = np.repeat(np.tile(self._binout.read(self._name, elout_elem, 'mat')[0], time.shape[0]).flatten(),
+                                nip).reshape((-1, 1))
+                ipts = self._concatenated_ranges(nip).reshape(-1, 1)
+                ids = np.repeat(np.tile(self._binout.read(self._name, elout_elem, 'ids')[0], time.shape[0]).flatten(),
+                                nip).reshape((-1, 1))
 
         elif (elout_elem == "shell" and what == "strain"):
             # ok
