@@ -7,6 +7,7 @@ from ..utils.constants import VPSDataConstant, DataChannelTypesNodout, DataChann
 
 
 class VPSData:
+    """ """
 
     def __init__(self, vps_file_path):
 
@@ -22,6 +23,15 @@ class VPSData:
         self.dynasaur_definitions = DynasaurDefinitions(logger)
 
     def _get_available_data_types_dict(self, name, node):
+        """
+
+        Args:
+          name: 
+          node: 
+
+        Returns:
+
+        """
         if isinstance(node, h5py.Dataset):
             if node.name.split("/")[-1] == 'res':  # result of data
                 if node.parent.name.split("/")[5] in [VPSDataConstant.NODE]:
@@ -40,6 +50,14 @@ class VPSData:
                     self._set_part_energy_elements(node)
 
     def _args_to_data(self, args):
+        """
+
+        Args:
+          args: 
+
+        Returns:
+
+        """
         data_type = ""
         data_channel = ""
 
@@ -103,6 +121,14 @@ class VPSData:
             return np.linalg.norm(f[search_string][:, :, idx], axis=axis)
 
     def read(self, *argv):
+        """
+
+        Args:
+          *argv: 
+
+        Returns:
+
+        """
         read_argv = []
 
         # 4 cases
@@ -133,6 +159,14 @@ class VPSData:
                 return []
 
     def _get_node_index_and_data_channel(self, arg):
+        """
+
+        Args:
+          arg: 
+
+        Returns:
+
+        """
         # NODE
         if arg == DataChannelTypesNodout.X_COORDINATE or \
                 arg == DataChannelTypesNodout.Y_COORDINATE or arg == DataChannelTypesNodout.Z_COORDINATE:
@@ -170,6 +204,14 @@ class VPSData:
         return idx, data_channel
 
     def _get_part_energy_index_and_data_channel(self, arg):
+        """
+
+        Args:
+          arg: 
+
+        Returns:
+
+        """
         # MATSUM
         if arg == "hourglass_energy":
             idx = [0]
@@ -191,6 +233,14 @@ class VPSData:
         return idx, data_channel
 
     def _get_global_energy_index_and_data_channel(self, arg):
+        """
+
+        Args:
+          arg: 
+
+        Returns:
+
+        """
         # GLSTAT
         if arg == DataChannelTypesGlobalEnergy.EXTERNAL_WORK:
             idx = 0
@@ -224,6 +274,14 @@ class VPSData:
         return idx, data_channel
 
     def _get_secforc_index_and_data_channel(self, arg):
+        """
+
+        Args:
+          arg: 
+
+        Returns:
+
+        """
         # SECTION
         if arg == DataChannelTypesSecforc.X_CENTROID or \
                 arg == DataChannelTypesSecforc.Y_CENTROID or arg == DataChannelTypesSecforc.Z_CENTROID:
@@ -254,6 +312,14 @@ class VPSData:
         return idx, data_channel
 
     def _get_part_index_and_data_channel(self, arg):
+        """
+
+        Args:
+          arg: 
+
+        Returns:
+
+        """
         if arg == None:
             idx = 0
             data_channel = "abc"
@@ -265,6 +331,14 @@ class VPSData:
         return idx, data_channel
 
     def _get_contact_index_and_data_channel(self, arg):
+        """
+
+        Args:
+          arg: 
+
+        Returns:
+
+        """
         if arg == DataChannelTypesContact.X_FORCE or \
              arg == DataChannelTypesContact.Y_FORCE or arg == DataChannelTypesSecforc.Z_FORCE:
             idx = [0] if arg.startswith("x") else ([1] if arg.startswith("y") else [2])
@@ -281,6 +355,14 @@ class VPSData:
         return idx, data_channel
 
     def _set_node_elements(self, node):
+        """
+
+        Args:
+          node: 
+
+        Returns:
+
+        """
         if VPSDataConstant.NODOUT not in self._d.keys():
             self._d[VPSDataConstant.NODOUT] = ["ids", "time"]
         idx_of_data = node.parent.name.split("/").index(node.parent.name.split("/")[5]) + 1
@@ -315,6 +397,14 @@ class VPSData:
                                                     DataChannelTypesNodout.RZ_ACCELERATION])
 
     def _set_contact_elements(self, node):
+        """
+
+        Args:
+          node: 
+
+        Returns:
+
+        """
         if VPSDataConstant.RCFORC not in self._d.keys():
             self._d[VPSDataConstant.RCFORC] = ["ids", "time"]
         idx_of_data = node.parent.name.split("/").index(node.parent.name.split("/")[5]) + 1
@@ -325,6 +415,14 @@ class VPSData:
                                                      DataChannelTypesContact.Z_FORCE])
 
     def _set_global_energy_elements(self, node):
+        """
+
+        Args:
+          node: 
+
+        Returns:
+
+        """
         if VPSDataConstant.GLSTAT not in self._d.keys():
             self._d[VPSDataConstant.GLSTAT] = ["ids", "time"]
         idx_of_data = node.parent.name.split("/").index(node.parent.name.split("/")[5]) + 1
@@ -350,6 +448,14 @@ class VPSData:
             self._d[VPSDataConstant.GLSTAT].extend(["added_mass"])
 
     def _set_part_energy_elements(self, node):
+        """
+
+        Args:
+          node: 
+
+        Returns:
+
+        """
         if VPSDataConstant.MATSUM not in self._d.keys():
             self._d[VPSDataConstant.MATSUM] = ["ids", "time"]
 
@@ -375,6 +481,14 @@ class VPSData:
 
 
     def _set_section_elements(self, node):
+        """
+
+        Args:
+          node: 
+
+        Returns:
+
+        """
         if node.parent.name.split("/")[5] == VPSDataConstant.SECTION:
             if VPSDataConstant.SECFORC not in self._d.keys():
                 self._d[VPSDataConstant.SECFORC] = ["ids", "time"]
