@@ -89,7 +89,7 @@ class CriteriaController(Plugin, PluginInterface):
             self._data_dict[part_of].update({type_of_criteria: {}})
 
         if criteria_name not in self._data_dict[part_of][type_of_criteria].keys():
-            value_unit = value.units if isinstance(value, pint.Quantity) else "unknow"
+            value_unit = value.units if isinstance(value, pint.Quantity) else "dimensionless"
             value = value.magnitude if isinstance(value, pint.Quantity) else value
             if isinstance(value, np.ndarray):
                 assert(len(value) == 1)
