@@ -181,6 +181,8 @@ class JointTypeMapping:
     @staticmethod
     def lspp_to_dynasaur_mapping(channel_type):
         """
+        Searches for the identifier in JointTypeMapping.
+        If channel_type is missing in the list, the original value is returned (i.e. time)
 
         Args:
           binary_data_type: return:
@@ -193,6 +195,8 @@ class JointTypeMapping:
             if tpl[1] == channel_type:
                 return tpl[0]
 
+        return channel_type
+
 
 class DataTypeMapping:
     """ """
