@@ -5,6 +5,7 @@ class Units:
     def __init__(self, length="m",
                  time="s",
                  mass="kg",
+                 angle="rad",
                  temperature="K",
                  luminosity="cd",
                  current="A",
@@ -20,6 +21,9 @@ class Units:
         self._validate_unit(mass, "[mass]")
         self.mass = self.ureg(mass)
 
+        self._validate_unit(angle, "dimensionless")
+        self.angle = self.ureg(angle)
+
         self._validate_unit(temperature, "[temperature]")
         self.temperature = self.ureg(temperature)
 
